PFNKTXITERCB

Type Alias PFNKTXITERCB 

pub type PFNKTXITERCB = Option<unsafe extern "C" fn(miplevel: c_int, face: c_int, width: c_int, height: c_int, depth: c_int, faceLodSize: ktx_uint64_t, pixels: *mut c_void, userdata: *mut c_void) -> ktx_error_code_e>;
@memberof ktxTexture @~English @brief Signature of function called by the ktxTexture_Iterate* functions to receive image data.

The function parameters are used to pass values which change for each image. Obtain values which are uniform across all images from the @c ktxTexture object.

@param [in] miplevel MIP level from 0 to the max level which is dependent on the texture size. @param [in] face usually 0; for cube maps, one of the 6 cube faces in the order +X, -X, +Y, -Y, +Z, -Z, 0 to 5. @param [in] width width of the image. @param [in] height height of the image or, for 1D textures textures, 1. @param [in] depth depth of the image or, for 1D & 2D textures, 1. @param [in] faceLodSize number of bytes of data pointed at by @p pixels. @param [in] pixels pointer to the image data. @param [in,out] userdata pointer for the application to pass data to and from the callback function.

Aliased Type

pub enum PFNKTXITERCB {
    None,
    Some(unsafe extern "C" fn(i32, i32, i32, i32, i32, u64, *mut c_void, *mut c_void) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(i32, i32, i32, i32, i32, u64, *mut c_void, *mut c_void) -> i32)

Some value of type T.